@@ -1,4 +1,4 @@
-package Pcore::PDF v0.3.2;
+package Pcore::PDF v0.3.3;
 
 use Pcore -dist, -class, -const, -result;
 use Config;
@@ -137,7 +137,7 @@ sub remove_logo ( $self, $pdf_ref ) {
 }
 
 sub _generate_mswin ( $self ) {
-    return if $self->{_threads} >= $self->{max_threads};
+    return if $self->{_threads} >= 1;             # $self->{max_threads};
 
     return unless my $task = shift $self->{_queue}->@*;
 
@@ -374,7 +374,7 @@ __END__
 
 =head1 NAME
 
-Pcore::PDF - HTML to PDF convertor
+Pcore::PDF - non-blocking HTML to PDF convertor
 
 =head1 SYNOPSIS
 
@@ -425,7 +425,7 @@ Maximum number of princexml processes. Under Windows this value should be 1, und
 
 =item generate_pdf( $self, $html, $cb )
 
-Generates PDF from $html template.
+Generates PDF from C<$html> template. Call C<$cb->($result)> on finish, where C<$result> is standard Pcore API result object, see Pcore docuentation.
 
 =back
 
